@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import contrast
 from contrast.agent import scope
@@ -57,7 +57,7 @@ def skip_analysis(context):
     return not SettingsState().is_assess_enabled()
 
 
-def _analyze(patch_policy, preshift, self_obj, ret, args, kwargs=None):
+def _analyze(patch_policy, preshift, self_obj, ret, orig_args, orig_kwargs=None):
     if not patch_policy:
         return
 
@@ -65,17 +65,49 @@ def _analyze(patch_policy, preshift, self_obj, ret, args, kwargs=None):
     if context is None:
         return
 
+    if patch_policy.analysis_func is not None:
+
+        rule = (
+            patch_policy.trigger_nodes[0].rule if patch_policy.trigger_nodes else None
+        )
+
+        patch_policy.analysis_func(
+            rule=rule,
+            nodes=patch_policy.all_nodes,
+            self_obj=self_obj,
+            ret=ret,
+            orig_args=orig_args,
+            orig_kwargs=orig_kwargs,
+            preshift=preshift,
+        )
+    else:
+        _run_unoptimized_analysis(
+            patch_policy, preshift, self_obj, ret, orig_args, orig_kwargs
+        )
+
+
+def _run_unoptimized_analysis(patch_policy, preshift, self_obj, ret, args, kwargs):
     if patch_policy.trigger_nodes:
         # Each node may potentially correspond to a different rule
         for node in patch_policy.trigger_nodes:
-            if not scope.in_trigger_scope():
-                with scope.trigger_scope():
-                    trigger_policy.apply(node.rule, [node], ret, args, kwargs)
+            trigger_policy.apply(
+                rule=node.rule,
+                nodes=[node],
+                ret=ret,
+                orig_args=args,
+                orig_kwargs=kwargs,
+            )
 
     if patch_policy.source_nodes:
-        source_policy.apply(patch_policy.source_nodes, self_obj, ret, args, kwargs)
+        source_policy.apply(
+            nodes=patch_policy.source_nodes,
+            self_obj=self_obj,
+            ret=ret,
+            orig_args=args,
+            orig_kwargs=kwargs,
+        )
 
-    if not scope.in_propagation_scope():
-        if patch_policy.propagator_nodes:
-            with scope.propagation_scope():
-                propagation_policy.apply(patch_policy.propagator_nodes, preshift, ret)
+    if patch_policy.propagator_nodes:
+        propagation_policy.apply(
+            nodes=patch_policy.propagator_nodes, preshift=preshift, ret=ret
+        )
