@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
+import types
+
 from contrast.extern import wrapt
 
 import contrast
@@ -11,7 +13,7 @@ from contrast.agent.assess.policy.analysis import analyze
 from contrast.utils.patch_utils import add_watermark
 
 
-def build_assess_method(original_method, patch_policy):
+def build_assess_method_legacy(original_method, patch_policy):
     """
     Creates method to replace old method and call our assess code with the original method
 
@@ -36,9 +38,14 @@ def build_assess_method(original_method, patch_policy):
     return add_watermark(assess_method)
 
 
-def build_assess_method_wrapt(original_method, patch_policy):
+def build_assess_method(original_method, patch_policy):
     """
     identical to build_assess_method, but with a wrapt wrapper
+
+    From the wrapt documentation:
+        In all cases, the wrapped function passed to the wrapper function is called
+        in the same way, with args and kwargs being passed. The instance argument
+        doesn't need to be used in calling the wrapped function.
     """
 
     @wrapt.function_wrapper
@@ -51,10 +58,13 @@ def build_assess_method_wrapt(original_method, patch_policy):
             result = None
             raise
         finally:
+            if instance is not None and not isinstance(instance, types.ModuleType):
+                args = (instance, *args)
             analyze(context, patch_policy, result, args, kwargs)
 
         return result
 
+    # note that this function likely already has our watermark
     return add_watermark(assess_method_wrapper(original_method))
 
 
@@ -155,19 +165,19 @@ class CachedPropertyProxy(wrapt.ObjectProxy):
     cs__patch_policy = None
 
     def __init__(self, wrapped, attr_name, patch_policy):
-        super(CachedPropertyProxy, self).__init__(wrapped)
+        super().__init__(wrapped)
         self.cs__patch_policy = patch_policy
         self.cs__attr_name = attr_name
 
-    def __get__(self, *args, **kwargs):
+    def __get__(__cs_self, *args, **kwargs):
         context = contrast.CS__CONTEXT_TRACKER.current()
-        result = self.__wrapped__.__get__(*args, **kwargs)
+        result = __cs_self.__wrapped__.__get__(*args, **kwargs)
 
         try:
             # Self is the only arg that seems to be relevant for policy/reporting
-            args = (self.__wrapped__,)
-            analyze(context, self.cs__patch_policy, result, args, {})
+            args = (__cs_self.__wrapped__,)
+            analyze(context, __cs_self.cs__patch_policy, result, args, {})
         except Exception:
-            logger.exception("Failed to apply policy for %s", self.cs__attr_name)
+            logger.exception("Failed to apply policy for %s", __cs_self.cs__attr_name)
 
         return result
