@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.extern.six import iteritems, PY2, PY3
 
 import contrast
+from contrast.agent import scope
 from contrast.agent.assess.contrast_event import ContrastEvent
 from contrast.agent.assess.policy.propagation_node import PropagationNode
 from contrast.agent.assess.policy.propagators import (
@@ -34,19 +34,21 @@ logger = logging.getLogger("contrast")
 
 
 @log_time("applying propagation policy")
-def apply(nodes, preshift, ret):  # pylint: disable=redefined-builtin
+def apply(nodes, preshift, ret, **kwargs):  # pylint: disable=redefined-builtin
     if not nodes:
         return
 
-    for node in nodes:
-        if not preshift:
-            continue
+    if not scope.in_propagation_scope():
+        with scope.propagation_scope():
+            for node in nodes:
+                if not preshift:
+                    continue
 
-        target = node.get_matching_first_target(
-            preshift.obj, ret, preshift.args, preshift.kwargs
-        )
+                target = node.get_matching_first_target(
+                    preshift.obj, ret, preshift.args, preshift.kwargs
+                )
 
-        apply_propagator(node, preshift, target, ret)
+                apply_propagator(node, preshift, target, ret)
 
 
 def track_copy_without_new_event(target, self_obj):
@@ -229,7 +231,7 @@ def apply_propagator(propagator_node, preshift, target, ret):
         return
 
     if isinstance(target, dict):
-        for key, value in iteritems(target):
+        for key, value in target.items():
             apply_propagator(propagator_node, preshift, key, ret)
             apply_propagator(propagator_node, preshift, value, ret)
     else:
@@ -256,5 +258,4 @@ def propagate_string(propagator_node, preshift, target, ret):
     logger.debug(
         "Propagator %s found: propagated to %s", propagator_node.name, id(target)
     )
-
     context.propagated()
