@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import copy
 
@@ -34,7 +34,7 @@ class EncodeHtmlSplatPropagator(SplatPropagator):
         if hasattr(string_to_escape, "__html__"):
             self.node.tags.discard("HTML_ENCODED")
 
-        super(EncodeHtmlSplatPropagator, self).propagate()
+        super().propagate()
 
     def reset_tags(self):
         self.node.tags = self.original_tags
