@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import sys
 
@@ -105,17 +105,15 @@ class HardcodedValueRule(StaticRule, CodeParserMixin):
             constant_name = constant
         else:
             source = sys.modules[cls_or_module.__module__].__file__
-            source_name = "{0.__module__}.{0.__name__}".format(cls_or_module)
-            constant_name = "{}.{}".format(cls_or_module.__name__, constant)
+            source_name = f"{cls_or_module.__module__}.{cls_or_module.__name__}"
+            constant_name = f"{cls_or_module.__name__}.{constant}"
 
         logger.debug("Reporting finding in %s for %s", source_name, constant)
 
         properties = {}
         properties[self.SOURCE] = source
         properties[self.CONSTANT_NAME] = constant
-        properties[self.CODE_SOURCE] = "{}{}".format(
-            constant_name, self.redacted_marker
-        )
+        properties[self.CODE_SOURCE] = f"{constant_name}{self.redacted_marker}"
 
         self.build_and_send_finding(
             properties, source_name=source_name, constant=constant
