@@ -1,10 +1,8 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import os
 
-from contrast.extern import six
-
 from contrast.agent.settings_state import SettingsState
 from contrast.agent.assess.rules.dataflow_rule import DataflowRule
 from contrast.api import Finding
@@ -39,22 +37,20 @@ class TriggerConfigRule(DataflowRule):
 
     def _create_filename(self, frame):
         filename = frame.file_name.rstrip(".py").replace(".", os.sep) + ".py"
-        return "{}:{}".format(filename, frame.line_number)
+        return f"{filename}:{frame.line_number}"
 
     def _create_snippet(self, node, target, event):
         # Rely only on kwarg param for reporting
-        source = [x for x in node.sources if isinstance(x, six.text_type)][0]
-        params = "{}={}".format(source, target)
+        source = [x for x in node.sources if isinstance(x, str)][0]
+        params = f"{source}={target}"
 
         method_name = (
-            "{}.{}".format(
-                event.stack[0].declaring_class.rstrip(".py"), event.stack[0].method_name
-            )
+            f"{event.stack[0].declaring_class.rstrip('.py')}.{event.stack[0].method_name}"
             if event.stack[0].declaring_class.startswith(node.module)
             else node.name
         )
 
-        return "{}({})".format(method_name, params)
+        return f"{method_name}({params})"
 
     def create_finding(self, orig_properties, node, target, events, **kwargs):
         """
