@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from __future__ import print_function
 import platform
 import sys
 
 from contrast import __version__, AGENT_CURR_WORKING_DIR
+from contrast.reporting.teamserver_messages import ServerActivity
 from contrast.agent.patch_controller import disable_assess_patches
 from contrast.agent import patch_controller, service_client, scope
+from contrast.agent.telemetry import telemetry_disabled
 from contrast.agent.policy.loader import Policy
 from contrast.agent.assess.policy import trigger_policy
 from contrast.agent.assess.preflight import update_preflight_hashes
@@ -16,6 +18,7 @@ from contrast.agent.middlewares.route_coverage.routes_mixin import RoutesMixin
 from contrast.agent.settings_state import SettingsState
 from contrast.agent.speedracer_input_analysis import get_input_analysis
 from contrast.api.dtm_pb2 import AttackResult
+from contrast.reporting import ReportingClient
 from contrast.utils.decorators import cached_property
 from contrast.utils.exceptions.contrast_service_exception import (
     ContrastServiceException,
@@ -28,10 +31,11 @@ from contrast.utils.loggers.logger import setup_agent_logger, setup_basic_agent_
 from contrast.utils.timer import now_ms_float, now_ms
 from contrast.assess_extensions import cs_str
 
-if sys.version_info >= (3, 7) and sys.version_info < (3, 10):
+if not telemetry_disabled():
     from contrast.agent.telemetry import Telemetry
 else:
     Telemetry = None
+
 # initialize a basic logger until config is parsed
 logger = setup_basic_agent_logger()
 
@@ -51,7 +55,6 @@ class BaseMiddleware(RoutesMixin):
     Pre -> get_response -> post
     """
 
-    MIDDLEWARE_IMPORT_DEPRECATED = False
     _loaded = False
     app_name = ""  # This should be overridden by child classes
 
@@ -63,18 +66,6 @@ class BaseMiddleware(RoutesMixin):
     )
     LOGS_SEPARATOR = "-" * 120
 
-    MIDDLEWARE_DEPRECATION_MSG = (
-        "[Contrast Security] [DEPRECATION] Agent version 5.0.0 will drop support "
-        "for middleware imports through contrast.agent.middlewares "
-        "in December 2021. See https://docs.contrastsecurity.com/en/python-middleware.html "
-        "for updated installation instructions."
-    )
-
-    PYTHON_DEPRECATION_MSG = (
-        "[Contrast Security] [DEPRECATION] Agent version 5.0.0 will drop support for Python {}.{} in December 2021. "
-        "Please contact Customer Support prior if you require continued support."
-    )
-
     def __init__(self):
         """
         If this method is called more than once per process, we use the _loaded
@@ -117,24 +108,8 @@ class BaseMiddleware(RoutesMixin):
         setup_agent_logger(self.settings.config)
         self.settings.config.log_config()
 
-        if sys.version_info[0:2] <= (3, 6):
-            self.log_deprecation(
-                self.PYTHON_DEPRECATION_MSG.format(
-                    sys.version_info.major, sys.version_info.minor
-                )
-            )
-
-        if self.MIDDLEWARE_IMPORT_DEPRECATED:
-            self.log_middleware_deprecation()
-
         if not BaseMiddleware._loaded:
-            logger.debug(
-                "Use contextvars for Scope and Request Context storage: %s",
-                cs_str.USE_CONTEXTVARS,
-            )
-
-            if cs_str.USE_CONTEXTVARS:
-                cs_str.init_contrast_scope_cvars()
+            cs_str.init_contrast_scope_cvars()
 
         if not BaseMiddleware._loaded and not self.initialize_service_client():
             logger.error("Unable to initialize Contrast Agent.")
@@ -144,11 +119,14 @@ class BaseMiddleware(RoutesMixin):
         self.log_environment()
         self.warn_for_misleading_config()
 
-        if (
-            not BaseMiddleware._loaded
-            and sys.version_info >= (3, 7)
-            and sys.version_info < (3, 10)
-        ):
+        self.reporting_client = (
+            ReportingClient() if self.settings.config.is_service_bypassed else None
+        )
+
+        if self.reporting_client is not None:
+            self.reporting_client.start()
+
+        if not BaseMiddleware._loaded and Telemetry is not None:
             self.telemetry = Telemetry()
             self.telemetry.start()
 
@@ -160,7 +138,7 @@ class BaseMiddleware(RoutesMixin):
         if self.settings.is_assess_enabled():
             # For now agent runtime starts before config scanning
             # this will be reset when time_limit_threshold is reached,
-            # it doesn't simbolize the total agent runtime for all time.
+            # it doesn't symbolize the total agent runtime for all time.
             self.settings.agent_runtime_window = now_ms()
 
             if not BaseMiddleware._loaded:
@@ -223,7 +201,7 @@ class BaseMiddleware(RoutesMixin):
         """
         Log current working directory, python version and pip version
         """
-        banner = "{0}ENVIRONMENT{0}".format("-" * 50)
+        banner = f"{'-' * 50}ENVIRONMENT{'-' * 50}"
         logger.debug(banner)
         logger.debug("Current Working Dir: %s", AGENT_CURR_WORKING_DIR)
         logger.debug("Python Version: %s", sys.version)
@@ -256,9 +234,13 @@ class BaseMiddleware(RoutesMixin):
         # Passing callback to send message due to a circular import issue, and a
         # deadlock occurring if something is imported inside of a function running in
         # this thread
-        self.library_reader = LibraryReader(
-            send_message_func=service_client.send_messages
+        send_message_func = (
+            self.reporting_client.add_message
+            if self.reporting_client
+            else service_client.send_messages
         )
+
+        self.library_reader = LibraryReader(send_message_func=send_message_func)
         self.library_reader.start_library_analysis_thread()
 
     def is_agent_enabled(self):
@@ -324,7 +306,15 @@ class BaseMiddleware(RoutesMixin):
 
             logger.debug("Sending final messages for reporting.")
 
-            service_client.send_messages(self.final_messages(context))
+            if self.reporting_client:
+                for msg in self.final_ts_messages():
+                    self.reporting_client.add_message(msg)
+
+            final_messages = self.final_messages(context)
+            service_client.send_messages(final_messages)
+
+    def final_ts_messages(self):
+        return [ServerActivity()]
 
     def final_messages(self, context):
         # Request body is truncated to not overwhelm ContrastUI.
@@ -508,11 +498,7 @@ class BaseMiddleware(RoutesMixin):
 
         trigger_node, args = self.trigger_node
 
-        # TODO: PYT-721 this trigger scope is already and shouldn't be required.
-        # If/when we consolidate all scope levels, this scope should be removed
-        # entirely since the postfilter is already in scope when it's called.
-        with scope.trigger_scope():
-            trigger_policy.apply(rule, [trigger_node], result, args, {})
+        trigger_policy.apply(rule, [trigger_node], result, args)
 
     def postfilter_assess(self, context):
         """
@@ -574,11 +560,12 @@ class BaseMiddleware(RoutesMixin):
         """
         for result in context.activity.results:
             if result.response == AttackResult.BLOCKED:
-                msg = "Rule {} threw a security exception".format(result.rule_id)
+                msg = f"Rule {result.rule_id} threw a security exception"
                 raise SecurityException(None, message=msg)
 
     def log_start_request_analysis(self, request_path):
         self.request_start_time = now_ms_float()
+
         logger.debug("Beginning request analysis", request_path=request_path)
 
     def log_end_request_analysis(self, request_path):
@@ -619,17 +606,4 @@ class BaseMiddleware(RoutesMixin):
         Not all frameworks we support will necessarily have config scanning rules.
         Those that do should override this method.
         """
-        logger.debug("No config scanning rules for %s", self.__class__.__name__)
-
-    @staticmethod
-    def log_deprecation(msg):
-        warn_color = "\033[91m"
-        end_color = "\033[0m"
-
-        print("\n{}{}{}\n".format(warn_color, msg, end_color))
-
-        logger.warning(msg)
-
-    @staticmethod
-    def log_middleware_deprecation():
-        BaseMiddleware.log_deprecation(BaseMiddleware.MIDDLEWARE_DEPRECATION_MSG)
+        logger.debug(f"No config scanning rules for {self.__class__.__name__}")
