@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.middlewares.route_coverage.coverage_utils import CoverageUtils
 from contrast.api import Finding
@@ -45,7 +45,7 @@ class RoutesMixin(object):
             self.routes = routes
 
             routes_to_log = [
-                "{}: {}".format(route.verb, route.url) for route in self.routes.values()
+                f"{route.verb}: {route.url}" for route in self.routes.values()
             ]
             logger.debug("Found the following routes: %s", routes_to_log)
 
@@ -63,7 +63,7 @@ class RoutesMixin(object):
         if func is None:
             return
 
-        request_method = context.request.method
+        request_method = request.method
         route_id = CoverageUtils.build_key(str(id(func)), request_method)
 
         self.update_route_information(context, route_id, request_method, func)
