@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.extern.six import iteritems
 from contrast.api.dtm_pb2 import Activity, Finding as FindingDtm
 
 from contrast.utils.string_utils import protobuf_safe
@@ -29,7 +28,7 @@ class Finding(object):
 
         finding.rule_id = protobuf_safe(rule.name)
 
-        for key, value in iteritems(properties):
+        for key, value in properties.items():
             finding.properties[key] = value
 
         hash_code = rule.generate_preflight_hash(**kwargs)
