@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 """
 Rule applicator for SQLi for dbapi2-compliant modules
@@ -11,35 +11,16 @@ from contrast.agent.policy.loader import Policy
 from contrast.agent.assess.policy.analysis import skip_analysis
 from contrast.agent.assess.policy import trigger_policy
 from contrast.agent.settings_state import SettingsState
-from contrast.applies import (
-    DATABASE_SQLITE,
-    DATABASE_PG,
-    DATABASE_MYSQL,
-    DATABASE_SQL_ALCHEMY,
-)
-from contrast.utils import inventory_utils
 from contrast.utils.decorators import fail_safely
 
 
-# This represents a map of adapters (modules) to underlying db technologies
-# The adapter name is used for policy lookup/trace reporting purposes, but the
-# technology name is used for inventory reporting.
-ADAPTER_TO_DATABASE = {
-    "sqlite3": DATABASE_SQLITE,
-    "pysqlite2.dbapi2": DATABASE_SQLITE,
-    "psycopg2": DATABASE_PG,
-    "pymysql": DATABASE_MYSQL,
-    "sqlalchemy": DATABASE_SQL_ALCHEMY,
-}
-
-
 @fail_safely("Error running SQLi assess rule")
-def assess_rule(context, adapter, method, result, args, kwargs):
+def assess_rule(context, adapter_name, method, result, args, kwargs):
     """
     Apply assess SQLi rule
 
     @param context: Current RequestContext instance
-    @param adapter: String representing the adapter module (e.g. "sqlite3")
+    @param adapter_name: String representing the adapter module (e.g. "sqlite3")
     @param method: String representing the database method (e.g. "execute")
     @param result: Object representing result of database action
     @param args: The args tuple passed to the original database function
@@ -53,13 +34,12 @@ def assess_rule(context, adapter, method, result, args, kwargs):
     policy = Policy()
 
     rule = policy.triggers["sql-injection"]
-    trigger_nodes = rule.find_trigger_nodes("{}.Cursor".format(adapter), method)
+    trigger_nodes = rule.find_trigger_nodes(f"{adapter_name}.Cursor", method)
 
-    with scope.trigger_scope():
-        trigger_policy.apply(rule, trigger_nodes, result, args, kwargs)
+    trigger_policy.apply(rule, trigger_nodes, result, args, kwargs)
 
 
-def apply_rule(adapter, method, orig_func, args, kwargs):
+def apply_rule(adapter_name, orig_func, args, kwargs):
     """
     Common API for applying SQLi rule (applies both protect and assess rules)
 
@@ -76,19 +56,17 @@ def apply_rule(adapter, method, orig_func, args, kwargs):
     an exception. Otherwise we won't detect vulnerable dataflows that may have
     just happened to result in an exception under testing.
 
-    @param adapter: String representing the adapter (e.g. "sqlite3")
-    @param method: String representing the database method (e.g. "execute")
+    @param adapter_name: String representing the adapter (e.g. "sqlite3")
     @param orig_func: Original function (i.e. the one replaced by the patch)
-    @param *args: The *args passed to the original database function
-    @param **kwargs: The **kwargs passed to the original database function
+    @param args: The args passed to the original database function
+    @param kwargs: The kwargs passed to the original database function
 
     @return: Returns the object that is returned by calling orig_func
     """
     context = contrast.CS__CONTEXT_TRACKER.current()
 
     if context is not None:
-        _report_inventory(context, adapter)
-        _protect_rule(context, adapter, method, args, kwargs)
+        _protect_rule(context, adapter_name, orig_func.__name__, args, kwargs)
 
     try:
         result = orig_func(*args, **kwargs)
@@ -97,30 +75,13 @@ def apply_rule(adapter, method, orig_func, args, kwargs):
         raise
     finally:
         if not skip_analysis(context):
-            assess_rule(context, adapter, method, result, args, kwargs)
+            assess_rule(context, adapter_name, orig_func.__name__, result, args, kwargs)
 
     return result
 
 
-@fail_safely("Error during database inventory reporting")
-def _report_inventory(context, adapter):
-    """
-    We report database inventory information every time we see any database call. This
-    is the only way we can get TS flowmap working properly.
-
-    Eventually, we'll need to be able to report the host, port, and database name too.
-    (TODO: PYT-1698)
-    """
-    vendor = ADAPTER_TO_DATABASE.get(adapter)
-    if not vendor:
-        return
-
-    db_inventory = dict(vendor=vendor)
-    inventory_utils.append_db(context.activity, db_inventory)
-
-
 @fail_safely("Error running SQLi protect rule")
-def _protect_rule(context, adapter, method, args, kwargs):
+def _protect_rule(context, adapter_name, method, args, kwargs):
     """
     Run protect SQLi analysis if it's enabled.
     """
@@ -130,13 +91,11 @@ def _protect_rule(context, adapter, method, args, kwargs):
     # args[0] is self, args[1] is the query
     sql = args[1]
 
-    database = ADAPTER_TO_DATABASE.get(adapter, adapter)
-
     # TODO: PYT-986: remove creating fake policy node and patch loc policy
     from contrast.agent.policy.patch_location_policy import PatchLocationPolicy
     from contrast.agent.policy.trigger_node import TriggerNode
 
-    trigger_node = TriggerNode(database, "unused", True, method, "ARG_0")
+    trigger_node = TriggerNode(adapter_name, "unused", True, method, "ARG_0")
     patch_policy = PatchLocationPolicy(trigger_node)
 
     rule = SettingsState().defend_rules.get(SqlInjection.NAME)
