@@ -1,5 +1,5 @@
 /*
- * Copyright © 2021 Contrast Security, Inc.
+ * Copyright © 2022 Contrast Security, Inc.
  * See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
  */
 /* Python requires its own header to always be included first */
@@ -15,10 +15,6 @@
 
 #include <contrast/assess/logging.h>
 
-#if PY_MAJOR_VERSION >= 3
-#define PY3
-#endif
-
 #define CONTRAST_MODULE_STR "contrast.assess_extensions"
 #define CONTRAST_LOGGER_STR "logger"
 #define CONTRAST_LOG_METHOD_STR "log"
@@ -54,11 +50,9 @@ void log_message_at_level(log_level_t level, const char *msg, ...) {
     }
 
     va_start(argptr, msg);
-#ifdef PY3
+
     string = PyUnicode_FromFormatV(msg, argptr);
-#else
-    string = PyString_FromFormatV(msg, argptr);
-#endif
+
     va_end(argptr);
 
     if (string == NULL) {
