@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.wsgi.middleware import WSGIMiddleware
 from contrast.agent.middlewares.app_finder import get_original_app_or_fail
@@ -24,7 +24,7 @@ class BottleMiddleware(WSGIMiddleware):
             and isinstance(orig_bottle_app, bottle.Bottle)
             else get_original_app_or_fail(app, bottle.Bottle)
         )
-        super(BottleMiddleware, self).__init__(_app, app_name="Bottle Application")
+        super().__init__(_app, app_name="Bottle Application")
 
     @fail_safely("Unable to get route coverage", return_value={})
     def get_route_coverage(self):
