@@ -1,3 +1,4 @@
+import re
 from collections import namedtuple
 import os
 
@@ -16,7 +17,6 @@ ENV_PREFIX = "CONTRAST"
 
 ConfigOption = namedtuple("ConfigOption", ["name", "default_value", "type_cast"])
 
-
 DEFAULT_SERVICE_HOST = "127.0.0.1"
 DEFAULT_SERVICE_PORT = 30555
 
@@ -25,12 +25,23 @@ PUBLIC_SASS_TEAMSERVER_TYPES = {
     "app.contrastsecurity.com": "SAAS_DEFAULT",
     "eval.contrastsecurity.com": "SAAS_POV",
     "ce.contrastsecurity.com": "SAAS_CE",
+    "app.contrastsecurity.jp": "SAAS_TOKYO",
+    "cs": "SAAS_",
 }
-PRIVATE_SASS_DOMAIN = "contrastsecurity.com"
-PRIVATE_SASS_TEAMSERVER_TYPE = "SAAS_CUSTOM"
 
-TESTING_TEAMSERVER_NAMES = ["darpa"]
+PRIVATE_SASS_TEAMSERVER_TYPE = "SAAS_CUSTOM"
+PRIVATE_SASS_DOMAIN = ["contrastsecurity.com", "contrastsecurity.jp"]
+
 TESTING_TEAMSERVER_TYPE = "TESTING"
+TESTING_TEAMSERVER_NAMES = [
+    "darpa",
+    "alpha.contrastsecurity.com",
+    "apptwo.contrastsecurity.com",
+    "teamserver-staging.contsec.jp",
+    "teamserver-staging.contsec.com",
+    "security-research.contrastsecurity.com",
+    "teamserver-ops.contsec.com",
+]
 
 
 class AgentConfig(object):
@@ -49,6 +60,8 @@ class AgentConfig(object):
         # socket will still take precedence if it exists
         self.check_for_service_config()
 
+        self.check_for_api_config()
+
     def get(self, key, default_value=None):
         return self._config.get(key, default_value)
 
@@ -82,11 +95,45 @@ class AgentConfig(object):
         Note that CLI args (sys.argv) are not supported. This may change if the
         agent becomes a runner.
         """
-        builders = [Agent, Application, Assess, Inventory, Protect, Root, Server]
+        builders = [Api, Agent, Application, Assess, Inventory, Protect, Root, Server]
 
         for builder in builders:
             builder().build(self._config)
 
+    def check_for_api_config(self):
+        """
+        Validate api configurations were set if agent communicates directly with
+        Contrast UI, without Contrast Service.
+
+        If any api configs are missing, log at ERROR and disable the agent.
+
+        Returns the missing values or an empty list if none were missing.
+        """
+        if not self.is_service_bypassed:
+            return []
+
+        api_keys = [
+            "api.url",
+            "api.service_key",
+            "api.api_key",
+            "api.user_name",
+        ]
+
+        missing_values = []
+        for key in api_keys:
+            val = self.get(key)
+            if not val:
+                missing_values.append(key)
+
+        if missing_values:
+            msg = (
+                f"Missing a required connection value for: {', '.join(missing_values)}"
+            )
+            logger.error(msg)
+            self.put("enable", False)
+
+        return missing_values
+
     def check_for_service_config(self):
         """
         Check for and log user-provided config values for connecting to SR.
@@ -118,27 +165,17 @@ class AgentConfig(object):
 
         if self.get(host_key):
             self.put(port_key, DEFAULT_SERVICE_PORT)
-            msg = "{} is not set. Falling back to default TCP socket host: {}, port: {}".format(
-                port_key, self.get(host_key), self.get(port_key)
-            )
+            msg = f"{port_key} is not set. Falling back to default TCP socket host: {self.get(host_key)}, port: {self.get(port_key)}"
         elif self.get(port_key):
             self.put(host_key, DEFAULT_SERVICE_HOST)
-            msg = "{} is not set. Falling back to default TCP socket host: {}, port: {}".format(
-                host_key, self.get(host_key), self.get(port_key)
-            )
+            msg = f"{host_key} is not set. Falling back to default TCP socket host: {self.get(host_key)}, port: {self.get(port_key)}"
         else:
             self.put(host_key, DEFAULT_SERVICE_HOST)
             self.put(port_key, DEFAULT_SERVICE_PORT)
-            msg = "Neither {} nor the pair of {} and {} are set. Falling back to default TCP socket host: {}, port: {}.".format(
-                socket_key,
-                host_key,
-                port_key,
-                self.get(host_key),
-                self.get(port_key),
-            )
+            msg = f"Neither {socket_key} nor the pair of {host_key} and {port_key} are set. Falling back to default TCP socket host: {self.get(host_key)}, port: {self.get(port_key)}."
 
         msg_prefix = "Missing a required connection value to the Contrast Service."
-        warn_msg = "{} {}".format(msg_prefix, msg)
+        warn_msg = f"{msg_prefix} {msg}"
 
         logger.warning(warn_msg)
 
@@ -148,6 +185,19 @@ class AgentConfig(object):
     def get_session_metadata(self):
         return self.get("application.session_metadata", "")
 
+    @cached_property
+    def is_service_bypassed(self):
+        bypass = self.get("agent.service.bypass", None)
+        is_bypassed = bool(bypass and str(bypass).lower() in ("1", "true"))
+
+        logger.debug("Service bypass is %s", "enabled" if is_bypassed else "disabled")
+
+        return is_bypassed
+
+    @cached_property
+    def is_request_audit_enabled(self):
+        return self.is_service_bypassed and self.get("api.request_audit.enable")
+
     @cached_property
     def teamserver_type(self):
         url = self.get("api.url")
@@ -157,17 +207,27 @@ class AgentConfig(object):
 
         for name, ts_type in PUBLIC_SASS_TEAMSERVER_TYPES.items():
             if name in url:
+
+                # This regex matches https://cs001.contrastsecurity.com
+                r_url = re.match(r".*(cs\d{3})\..*", url)
+                if r_url:
+                    # and gets the second group which is the matched in brackets cs001
+                    # adds it to the SAAS_ type and becomes SAAS_CS001
+                    numbers = r_url.group(1).upper()
+
+                    return ts_type + numbers
+
                 return ts_type
 
         for name in TESTING_TEAMSERVER_NAMES:
             if name in url:
                 return TESTING_TEAMSERVER_TYPE
 
-        return (
-            PRIVATE_SASS_TEAMSERVER_TYPE
-            if PRIVATE_SASS_DOMAIN in url
-            else DEFAULT_TEAMSERVER_TYPE
-        )
+        for name in PRIVATE_SASS_DOMAIN:
+            if name in url:
+                return PRIVATE_SASS_TEAMSERVER_TYPE
+
+        return DEFAULT_TEAMSERVER_TYPE
 
 
 class ConfigBuilder(object):
@@ -222,7 +282,7 @@ class Agent(ConfigBuilder):
     TOP_LEVEL = "agent"
 
     def __init__(self):
-        super(Agent, self).__init__()
+        super().__init__()
 
         self.default_options = [
             # Some logger default values are handled by the logger
@@ -247,6 +307,11 @@ class Agent(ConfigBuilder):
                 default_value=True,
                 type_cast=utils.str_to_bool,
             ),
+            ConfigOption(
+                name="python.enable_profiler",
+                default_value=False,
+                type_cast=utils.str_to_bool,
+            ),
             ConfigOption(
                 name="python.assess.use_pure_python_hooks",
                 default_value=False,
@@ -270,11 +335,39 @@ class Agent(ConfigBuilder):
         ]
 
 
+class Api(ConfigBuilder):
+    TOP_LEVEL = "api"
+
+    def __init__(self):
+        super().__init__()
+
+        self.default_options = [
+            ConfigOption(name="url", default_value="", type_cast=str),
+            ConfigOption(name="service_key", default_value="", type_cast=str),
+            ConfigOption(name="api_key", default_value="", type_cast=str),
+            ConfigOption(name="user_name", default_value="", type_cast=str),
+            ConfigOption(
+                name="request_audit.enable", default_value=False, type_cast=bool
+            ),
+            ConfigOption(
+                name="request_audit.path",
+                default_value=AGENT_CURR_WORKING_DIR,
+                type_cast=str,
+            ),
+            ConfigOption(
+                name="request_audit.requests", default_value=False, type_cast=bool
+            ),
+            ConfigOption(
+                name="request_audit.responses", default_value=False, type_cast=bool
+            ),
+        ]
+
+
 class Application(ConfigBuilder):
     TOP_LEVEL = "application"
 
     def __init__(self):
-        super(Application, self).__init__()
+        super().__init__()
 
         self.default_options = [
             ConfigOption(name="code", default_value="", type_cast=str),
@@ -297,7 +390,7 @@ class Assess(ConfigBuilder):
     TOP_LEVEL = "assess"
 
     def __init__(self):
-        super(Assess, self).__init__()
+        super().__init__()
 
         self.default_options = [
             ConfigOption(
@@ -350,7 +443,7 @@ class Inventory(ConfigBuilder):
     TOP_LEVEL = "inventory"
 
     def __init__(self):
-        super(Inventory, self).__init__()
+        super().__init__()
 
         self.default_options = [
             ConfigOption(
@@ -369,7 +462,7 @@ class Protect(ConfigBuilder):
     TOP_LEVEL = "protect"
 
     def __init__(self):
-        super(Protect, self).__init__()
+        super().__init__()
 
         self.default_options = [
             ConfigOption(
@@ -483,7 +576,7 @@ class Server(ConfigBuilder):
     TOP_LEVEL = "server"
 
     def __init__(self):
-        super(Server, self).__init__()
+        super().__init__()
 
         self.default_options = [
             ConfigOption(
@@ -501,7 +594,7 @@ class Root(ConfigBuilder):
     TOP_LEVEL = None
 
     def __init__(self):
-        super(Root, self).__init__()
+        super().__init__()
 
         self.default_options = [
             ConfigOption(name="enable", default_value=True, type_cast=utils.str_to_bool)
