@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 """
 Implementation of patches for the `re` module.
@@ -12,7 +12,6 @@ from contrast.extern import structlog as logging
 import sys
 
 from contrast.extern.wrapt import register_post_import_hook
-from contrast.extern import six
 
 import contrast
 from contrast.agent import scope
@@ -23,6 +22,7 @@ from contrast.agent.assess.policy.analysis import analyze
 from contrast.agent.assess.policy.propagators import regex_propagator
 from contrast.utils.decorators import fail_safely
 from contrast.utils.patch_utils import build_and_apply_patch
+from contrast.utils.string_utils import ensure_string
 
 logger = logging.getLogger("contrast")
 
@@ -36,7 +36,7 @@ def build_group_hook(original_func, patch_policy, propagator):
                 propagator(args[0], result, *args[1:])
         return result
 
-    group_hook.__name__ = six.ensure_str(patch_policy.method_name)
+    group_hook.__name__ = ensure_string(patch_policy.method_name)
     return group_hook
 
 
@@ -189,7 +189,7 @@ def build_sub_hook(original_func, policy_node):
 
         return retval
 
-    sub_hook.__name__ = six.ensure_str(policy_node.method_name)
+    sub_hook.__name__ = ensure_string(policy_node.method_name)
     return sub_hook
 
 
@@ -217,7 +217,7 @@ def build_re_assess_hook(original_func, patch_policy):
         _analyze_policy(patch_policy.name, result, args, kwargs)
         return result
 
-    assess_hook.__name__ = six.ensure_str(original_func.__name__)
+    assess_hook.__name__ = ensure_string(original_func.__name__)
     return assess_hook
 
 
@@ -234,7 +234,7 @@ def build_re_pattern_redos_hook(original_func, _):
         _trigger_redos(full_name, retval, args, kwargs)
         return retval
 
-    redos_hook.__name__ = six.ensure_str(method_name)
+    redos_hook.__name__ = ensure_string(method_name)
     return redos_hook
 
 
@@ -278,14 +278,12 @@ def patch_re(re_module):
         pattern_cls, "finditer", build_re_pattern_redos_hook, owner_name="re.Pattern"
     )
 
-    if six.PY3:
-        # fullmatch method is new in Py3
-        build_and_apply_patch(
-            pattern_cls,
-            "fullmatch",
-            build_re_pattern_redos_hook,
-            owner_name="re.Pattern",
-        )
+    build_and_apply_patch(
+        pattern_cls,
+        "fullmatch",
+        build_re_pattern_redos_hook,
+        owner_name="re.Pattern",
+    )
 
     build_and_apply_patch(
         match_cls,
