@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-import distutils.util
 import os
 import socket
 
@@ -98,9 +97,7 @@ def _load_config(file_path):
             # config yaml cannot be loaded but agent should continue on in case
             # env vars are configured
             msg_prefix = "YAML validator found an error."
-            msg = "{} Configuration path: [{}]. Line [{}]. Error: {}".format(
-                msg_prefix, ex.problem_mark.name, ex.problem_mark.line, ex.problem
-            )
+            msg = f"{msg_prefix} Configuration path: [{ex.problem_mark.name}]. Line [{ex.problem_mark.line}]. Error: {ex.problem}"
             logger.warning(msg)
 
     return None
@@ -145,11 +142,17 @@ def str_to_bool(val):
     """
     if isinstance(val, bool):
         return val
-
-    if val is None:
+    if not isinstance(val, str):
         return False
 
-    return bool(distutils.util.strtobool(val))
+    # The remainder of this function was ported from distutils
+    val = val.lower()
+
+    if val in ("y", "yes", "t", "true", "on", "1"):
+        return True
+    if val in ("n", "no", "f", "false", "off", "0"):
+        return False
+    raise ValueError(f"invalid truth value {val!r}")
 
 
 def get_env_key(key):
