@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import sys
 import logging
@@ -58,9 +58,7 @@ def setup_agent_logger(config):
 
     # print so it shows up in STDOUT
     print(
-        "Contrast Agent Logger Initialized: {} : {}".format(
-            logging.getLevelName(logger.level), path
-        )
+        f"Contrast Agent Logger Initialized: {logging.getLevelName(logger.level)} : {path}"
     )  # pylint: disable=superfluous-parens
 
 
@@ -168,15 +166,15 @@ def _lock_logger_attr(logger, logger_attr, config):
     logger.logger_attr will be True if the user provided a legitimate string,
     but will be False if the attr value is '' or None.
     """
-    attr_value = config.get("agent.logger.{}".format(logger_attr))
-    setattr(logger, "lock_{}".format(logger_attr), bool(attr_value))
+    attr_value = config.get(f"agent.logger.{logger_attr}")
+    setattr(logger, f"lock_{logger_attr}", bool(attr_value))
 
 
 class AgentFilter(logging.Filter):
     def __init__(self, progname=None):
         self.progname = progname
-        super(AgentFilter, self).__init__()
+        super().__init__()
 
     def filter(self, record):
         record.progname = self.progname
-        return super(AgentFilter, self).filter(record)
+        return super().filter(record)
