@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 """
 Using logger.info/debug/someOtherLevel() is not supported in this module. In order to get the correct
@@ -118,9 +118,9 @@ def add_frame_info(logger, method_name, event_dict):
     if frame_info and frame_info[0]:
         frame = frame_info[0]
 
-        event_dict["frame_info"] = "{}:{}:{}".format(
-            basename(frame.f_code.co_filename), frame.f_code.co_name, frame.f_lineno
-        )
+        event_dict[
+            "frame_info"
+        ] = f"{basename(frame.f_code.co_filename)}:{frame.f_code.co_name}:{frame.f_lineno}"
 
     return event_dict
 
