@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.extern.webob import Request, Response
 
@@ -15,6 +15,7 @@ from contrast.utils.exceptions.contrast_service_exception import (
 )
 
 from contrast.extern import structlog as logging
+from contrast.utils import Profiler
 
 logger = logging.getLogger("contrast")
 DEFAULT_WSGI_NAME = "wsgi_app"
@@ -33,19 +34,21 @@ class WSGIMiddleware(BaseMiddleware):
         else:
             self.app_name = DEFAULT_WSGI_NAME
 
-        super(WSGIMiddleware, self).__init__()
+        super().__init__()
 
         self.wsgi_app = wsgi_app
 
     def __call__(self, environ, start_response):
+
         self.orig_path_info = environ.get("PATH_INFO")
 
-        if self.is_agent_enabled():
-            context = RequestContext(environ)
-            with contrast.CS__CONTEXT_TRACKER.lifespan(context):
-                return self.call_with_agent(context, environ, start_response)
+        with Profiler(self.orig_path_info):
+            if self.is_agent_enabled():
+                context = RequestContext(environ)
+                with contrast.CS__CONTEXT_TRACKER.lifespan(context):
+                    return self.call_with_agent(context, environ, start_response)
 
-        return self.call_without_agent(environ, start_response)
+            return self.call_without_agent(environ, start_response)
 
     def call_with_agent(self, context, environ, start_response):
         self.log_start_request_analysis(environ.get("PATH_INFO"))
@@ -109,7 +112,7 @@ class WSGIMiddleware(BaseMiddleware):
         """
         Normal without middleware call
         """
-        super(WSGIMiddleware, self).call_without_agent()
+        super().call_without_agent()
         return self.wsgi_app(environ, start_response)
 
     def get_route_coverage(self):
